@@ -8,25 +8,32 @@ from collections import OrderedDict
 
 import boto3
 from hdfs3 import HDFileSystem
-from slack_sdk import WebClient
-from slack_sdk.errors import SlackApiError
 from Accuinsight.modeler.core.LcConst.LcConst import ENV_JUPYTER_HOME_DIR
 from Accuinsight.modeler.utils.runs_utils import ProgressPercentage
+from Accuinsight.modeler.clients.modeler_api import WorkspaceRestApi
+from Accuinsight.modeler.utils.os_getenv import get_os_env
+from Accuinsight.modeler.core.LcConst import LcConst
+from Accuinsight.modeler.entities.alarm import Alarm
 
 
 class Common(object):
     def __init__(self):
+        env_value = get_os_env('ENV')
+
         self.StorageInfo = None
         self.target_name = None
         self.save_path = None
         self.endpoint = None
         self.thresholds = None
-        self.token = None
-        self.channel_id = None
+        self.hook_url = None
         self.message = None
         self.feature_name = None
         self.data = None
         self.storage_info_from_set = OrderedDict()
+        self.workspace_alarm_api = WorkspaceRestApi(env_value[LcConst.BACK_END_API_URL],
+                                                    env_value[LcConst.BACK_END_API_PORT],
+                                                    env_value[LcConst.BACK_END_API_URI])
+        self.workspace_alarm = Alarm()
 
     def set_storage(self,
                     access_key=None,  # aws-s3
@@ -213,39 +220,55 @@ class Common(object):
             self.data = data
 
     @staticmethod
-    def _send_message(metric=None, current_value=None, message=None, thresholds=None, token=None, channel_id=None):
-        logger = logging.getLogger(__name__)
+    def _send_message(metric=None, current_value=None, message=None, thresholds=None, alarm_object=None, alarm_api=None):
+        if alarm_object:
+            messages = list()
 
-        if token is not None and channel_id is not None:
+            if thresholds:
+                if current_value >= thresholds:
+                    messages.append('[모델 학습 완료] ' + metric + '이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.')
 
-            if thresholds is not None:
-                try:
-                    if current_value >= thresholds:
-                        msg = '[모델 학습 완료] ' + metric + '이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.'
-                        response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-                except SlackApiError as e:
-                    logger.error(f"Error message: {e}")
+            if message:
+                if isinstance(message, str):
+                    messages.append(message)
+                elif isinstance(message, list):
+                    messages.extend(message)
+                else:
+                    raise ValueError("Wrong message input detected. Available type is 'str' and 'list'")
 
-            elif message is not None:
-                try:
-                    msg = message
-                    response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-                except SlackApiError as e:
-                    logger.error(f"Error message: {e}")
-        else:
-            pass
+            if messages:
+                for message in messages:
+                    alarm_object.message = message
+                    alarm_object.type = "Workspace"
+                    alarm_api.call_rest_api(alarm_object.get_alarm_param(), "alarm")
 
-    def set_slack(self, token=None, channel_id=None):
-        self.token = token
-        self.channel_id = channel_id
+    def set_slack(self, hook_url=None):
+        if hook_url:
+            self.workspace_alarm.notifiers['slack'] = hook_url
+
+    def unset_slack(self):
+        if 'slack' in self.workspace_alarm.notifiers.keys():
+            del self.workspace_alarm.notifiers['slack']
+
+    def set_mail(self, address=None):
+        if address:
+            self.workspace_alarm.notifiers['mail'] = address
+
+    def unset_mail(self):
+        if 'mail' in self.workspace_alarm.notifiers.keys():
+            del self.workspace_alarm.notifiers['mail']
 
     def send_message(self, message=None, thresholds=None):
-        if message is not None and thresholds is not None:
+        if message and thresholds:
             raise ValueError("'message'와 'thresholds' 두 개의 arguments를 동시에 입력할 수 없습니다.")
         else:
             self.message = message
             self.thresholds = thresholds
 
+    def unset_message(self):
+        self.message = None
+        self.thresholds = None
+
     def set_features(self, feature_names):
         if str(type(feature_names)) == "<class 'list'>":
             self.feature_name = feature_names
@@ -260,4 +283,4 @@ class Common(object):
             except AttributeError:
                 raise ValueError('입력값으로 list 또는 pandas.core.indexes.base.Index를 사용하시기 바랍니다.')
 
-        return feature_names
\ No newline at end of file
+        return feature_names
