@@ -10,6 +10,7 @@ class WorkspaceRun:
     """
         Object for running code and sending the result to backend.
     """
+
     def __init__(self):
         env_value = get_os_env('ENV')
 
@@ -18,21 +19,24 @@ class WorkspaceRun:
                                                   env_value[LcConst.BACK_END_API_PORT],
                                                   env_value[LcConst.BACK_END_API_URI])
         self.code_path = None
-        self.custom_args = None
+        self.custom_args = ''
 
     def exec_code(self):
         parser = argparse.ArgumentParser()
         parser.add_argument('--workspaceRunId', default=None)
         parser.add_argument('--codePath', default=None)
         parser.add_argument('--stopFlag', default=False)
-        parser.add_argument('--stopTimeout', default=60)
+        parser.add_argument('--stopTimeout', default=600)
         parser.add_argument('--args', default='')
 
         args, unknown = parser.parse_known_args()
         args_dict = vars(args)
 
+        if not args_dict['args'] == '':
+            self.custom_args = + args_dict['args']\
+                .replace('[[:space:]]', " ").replace('[[:equal:]]', '=').replace('[[:hyphen:]]', '--')
+
         self.code_path = args_dict['codePath']
-        self.custom_args = '--' + args_dict['args'].replace(',', " --").replace(':', '=')
         self.workspace_run_log.workspace_run_id = args_dict['workspaceRunId']
         self.workspace_run_log.stop_flag = args_dict['stopFlag']
         self.workspace_run_log.stop_timeout = args_dict['stopTimeout']
@@ -41,7 +45,7 @@ class WorkspaceRun:
             raise Exception("codePath cannot be none")
 
         try:
-            subprocess.run("python3 -u %s %s > /tmp/output_%s.log 2>&1" %
+            subprocess.run("python3 -u %s%s > /tmp/output_%s.log 2>&1" %
                            (self.code_path, self.custom_args, self.workspace_run_log.workspace_run_id),
                            shell=True, encoding='UTF-8').check_returncode()
             self.workspace_run_log.is_success = True
